#
# spec file for package cargo
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016 Michal Vyskocil, michal.vyskocil@opensuse.org
# Copyright (c) 2016 Kristoffer Gronlund, kgronlund@suse.com
# Copyright (c) 2017 Luke Jones, luke.nukem.jones@gmail.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global bootstrap_version 0.26.0
%global bootstrap_rustc_version 1.25.0
%global current_rustc_version 1.25.0
%global rust_arch %{_arch}
%global abi gnu
%ifarch armv7hl
%global rust_arch armv7
%global abi gnueabihf
%endif
%ifarch armv6hl
%global rust_arch arm
%global abi gnueabihf
%endif
%ifarch ppc64
%global rust_arch powerpc64
%endif
%ifarch ppc64le
%global rust_arch powerpc64le
%endif
# Must restrict the x86 build to i686 since i586 is currently unsupported
%ifarch %ix86
%global rust_arch i686
%endif
%global rust_triple %{rust_arch}-unknown-linux-%{abi}
%bcond_with cargo_bootstrap
Name:           cargo
Version:        0.26.0
Release:        lp150.2.3.4
Summary:        The Rust package manager
License:        MIT OR Apache-2.0
Group:          Development/Languages/Other
Url:            https://github.com/rust-lang/cargo
Source0:        cargo-%{version}.tar.gz
Source1:        vendor.tar.xz
Patch0:         update-config-guess.patch
BuildRequires:  cmake
BuildRequires:  curl
BuildRequires:  git
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libcrypto)
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(libgit2) >= 0.23
BuildRequires:  pkgconfig(libssh)
BuildRequires:  pkgconfig(libssh_threads)
BuildRequires:  pkgconfig(libssl)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(zlib)
Requires:       rust
Conflicts:      cargo
Conflicts:      cargo-bootstrap
ExclusiveArch:  x86_64 %{arm} aarch64 ppc64 ppc64le s390x
%ifarch %ix86
BuildArch:      i686
ExclusiveArch:  i586 i686
%endif
# There are no successful builds for less than TW or Leap 42.2, so bootstrap
# until such time that there is.
%if %{with cargo_bootstrap}
BuildRequires:  cargo-bootstrap = %{bootstrap_version}
BuildRequires:  rust-std-bootstrap = %{bootstrap_rustc_version}
BuildRequires:  rustc-bootstrap = %{bootstrap_rustc_version}
%else
BuildRequires:  cargo <= %{version}
BuildRequires:  rust <= %{current_rustc_version}
BuildRequires:  rust-std <= %{current_rustc_version}
%endif

%description
Cargo downloads your Rust project’s dependencies and compiles your project.

%prep
%setup -q -n cargo-%{version}
%setup -q -D -T -a 1 -n cargo-%{version}
#patch0 -p1
mkdir cargo-home
cat >cargo-home/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'
[source.vendored-sources]
directory = './vendor'
EOF

%build
# This should eventually migrate to distro policy
# Enable optimization, debuginfo, and link hardening.
export RUSTFLAGS="-Copt-level=3 -Cdebuginfo=2 -Clink-arg=-Wl,-z,relro,-z,now"

export LIBGIT2_SYS_USE_PKG_CONFIG=1
export CARGO_HOME=`pwd`/cargo-home/
cargo build --target=%{rust_triple} --release %{?_smp_mflags}

%install
mkdir build
export CARGO_HOME=`pwd`/cargo-home/

cargo install --root %{buildroot}%{_prefix}
rm %{buildroot}%{_prefix}/.crates.toml

mkdir -p %{buildroot}%{_mandir}/man1
install -Dm0644 src%{_sysconfdir}/man/cargo*.1 %{buildroot}%{_mandir}/man1/
install -Dm0644 src%{_sysconfdir}/cargo.bashcomp.sh %{buildroot}%{_sysconfdir}/bash_completion.d/cargo.sh
install -Dm0644 src%{_sysconfdir}/_cargo %{buildroot}%{_sysconfdir}/zsh/site-functions/_cargo

%files
%defattr(-,root,root)
%doc LICENSE-APACHE LICENSE-MIT README.md
%{_bindir}/cargo
%{_mandir}/man1/*
%config %{_sysconfdir}/bash_completion.d/cargo.sh
%dir %{_sysconfdir}/zsh
%dir %{_sysconfdir}/zsh/site-functions
%config %{_sysconfdir}/zsh/site-functions/_cargo

%changelog
* Fri May 11 2018 mmanu84@outlook.de
- adapt cargo bootstrap version to 0.26.0
- adapt rustc bootstrap version to 1.25.0
- adapt rustc to 1.25.0
* Thu May 10 2018 luc14n0@linuxmail.org
- Update to version 0.26.0:
  + No longer removes rust or rs prefixs/suffixs.
  + Now defaults to creating a binary crate, instead of a library
    crate.
* Tue May  1 2018 mmanu84@outlook.de
- update to 0.25.0
  + Added a workspace.default-members config that overrides implied --all in virtual workspaces.
  + Enable incremental by default on development builds. Also added configuration keys to Cargo.toml
    and .cargo/config to disable on a per-project or global basis respectively.
- Patch disabled
  * update-config-guess.patch
* Fri Mar 23 2018 mmanu84@outlook.de
- adapt rustc to 1.24.1
* Wed Feb 28 2018 mmanu84@outlook.de
- adapt cargo bootstrap version to 0.25.0
- adapt rustc bootstrap version to 1.24.0
* Tue Feb 20 2018 coolo@suse.com
- add update-config-guess.patch to update config.* from GNU to
  support riscv64 without rpm patching it - as the patch also
  updates the checksums while rpm does not
* Tue Jan 16 2018 mmanu84@outlook.de
- adapt cargo bootstrap version to 0.24
* Thu Jan  4 2018 jones_ld@protonmail.com
- update to 0.24.0
  + Cargo now supports alternative registries[cargo/4506]
  + Cargo now supports uninstallation of multiple packages[cargo/4561]
    eg. `cargo uninstall foo bar` uninstalls `foo` and `bar`.
  + Added unit test checking to `cargo check`[cargo/4592]
  + Cargo now lets you install a specific version
    using `cargo install --version`[cargo/4637]
- version 0.23.0
  + Cargo will now build multi file examples in subdirectories of the `examples`
    folder that have a `main.rs` file.[cargo/4496]
  + Changed `[root]` to `[package]` in `Cargo.lock`[cargo/4571] Packages with
    the old format will continue to work and can be updated with `cargo update`.
  + Now supports vendoring git repositories[cargo/3992]
* Fri Nov 24 2017 mmanu84@outlook.de
- adapt cargo bootstrap version to 0.23
- adapt rustc bootstrap version to 1.22.1
* Mon Nov 20 2017 mmanu84@outlook.de
- adapt cargo bootstrap version to 0.22
- adapt rustc bootstrap version to 1.21
- add armv6 support
* Tue Oct 17 2017 luke.nukem.jones@gmail.com
- Update to 0.22.0
  + You can now call cargo install with multiple package names
  + Cargo commands inside a virtual workspace will now implicitly pass --all
  + Added a [patch] section to Cargo.toml to handle prepublication dependencies RFC 1969
  + include & exclude fields in Cargo.toml now accept gitignore like patterns
  + Added the --all-targets option
  + Using required dependencies as a feature is now deprecated and emits a warning
* Tue Oct 17 2017 luke.nukem.jones@gmail.com
- Restrict x86 version to build i686 only
* Wed Sep 20 2017 opensuse@dstoecker.de
- adapt cargo bootstrap version to 0.20 and gitlib2 requirement to 0.23
* Mon Sep  4 2017 luke.nukem.jones@gmail.com
- Update to 0.21.0
  + [Cargo API token location moved from `~/.cargo/config` to
    `~/.cargo/credentials`.][cargo/3978]
  + [Cargo will now build `main.rs` binaries that are in sub-directories of
    `src/bin`.][cargo/4214] ie. Having `src/bin/server/main.rs` and
    `src/bin/client/main.rs` generates `target/debug/server` and `target/debug/client`
  + [You can now specify version of a binary when installed through
    `cargo install` using `--vers`.][cargo/4229]
  + [Added `--no-fail-fast` flag to cargo to run all benchmarks regardless of
    failure.][cargo/4248]
  + [Changed the convention around which file is the crate root.][cargo/4259]
  + [The `include`/`exclude` property in `Cargo.toml` now accepts gitignore paths
    instead of glob patterns][cargo/4270]. Glob patterns are now deprecated.
- Version 0.20.0
  + [Build scripts can now add environment variables to the environment
    the crate is being compiled in.
    Example: `println!("cargo:rustc-env=FOO=bar");`][cargo/3929]
  + [Subcommands now replace the current process rather than spawning a new
    child process][cargo/3970]
  + [Workspace members can now accept glob file patterns][cargo/3979]
  + [Added `--all` flag to the `cargo bench` subcommand to run benchmarks of all
    the members in a given workspace.][cargo/3988]
  + [Updated `libssh2-sys` to 0.2.6][cargo/4008]
  + [Target directory path is now in the cargo metadata][cargo/4022]
  + [Cargo no longer checks out a local working directory for the
    crates.io index][cargo/4026] This should provide smaller file size for the
    registry, and improve cloning times, especially on Windows machines.
  + [Added an `--exclude` option for excluding certain packages when using the
  ` --all` option][cargo/4031]
  + [Cargo will now automatically retry when receiving a 5xx error
    from crates.io][cargo/4032]
  + [The `--features` option now accepts multiple comma or space
    delimited values.][cargo/4084]
  + [Added support for custom target specific runners][cargo/3954]
* Mon Sep  4 2017 luke.nukem.jones@gmail.com
- Cleans up rust_triple and adds rust compiler args
- Removes i586 from buildable targets
* Fri Jun  9 2017 luke.nukem.jones@gmail.com
- Update to version 0.19.0
    + [Added partial Pijul support][cargo/3842] Pijul is a version control system in Rust.
    You can now create new cargo projects with Pijul using `cargo new --vcs pijul`
    + [Now always emits build script warnings for crates that fail to build][cargo/3847]
    + [Added Android build support][cargo/3885]
    + [Added `--bins` and `--tests` flags][cargo/3901] now you can build all programs
    of a certain type, for example `cargo build --bins` will build all
    binaries.
    + [Added support for haiku][cargo/3952]
* Thu Jun  8 2017 mimi.vx@gmail.com
- require rust
- use system libgit2
- use pkgconfig deps
* Fri Apr 28 2017 luke.nukem.jones@gmail.com
- Update to 0.18.0
  * [The `cargo check` command does a type check of a project without
  building it][cargo/3296]
  * [crates.io will display CI badges from Travis and AppVeyor, if
  specified in Cargo.toml][cargo/3546]
  * [crates.io will display categories listed in Cargo.toml][cargo/3301]
  * [Compilation profiles accept integer values for `debug`, in addition
  to `true` and `false`. These are passed to `rustc` as the value to
  `-C debuginfo`][cargo/3534]
  * [Implement `cargo --version --verbose`][cargo/3604]
  * [All builds now output 'dep-info' build dependencies compatible with
  make and ninja][cargo/3557]
  * [Build all workspace members with `build --all`][cargo/3511]
  * [Document all workspace members with `doc --all`][cargo/3515]
  * [Path deps outside workspace are not members][cargo/3443]
- Restrict version required for building
* Fri Mar 17 2017 luke.nukem.jones@gmail.com
- Remove reproducible.patch - has been upstreamed.
* Fri Mar 17 2017 luke.nukem.jones@gmail.com
- Update to 0.17.0
  * [The `cargo check` command does a type check of a project without
  building it][cargo/3296]
  * [crates.io will display CI badges from Travis and AppVeyor, if
  specified in Cargo.toml][cargo/3546]
  * [crates.io will display categories listed in Cargo.toml][cargo/3301]
  * [Compilation profiles accept integer values for `debug`, in addition
  to `true` and `false`. These are passed to `rustc` as the value to
  `-C debuginfo`][cargo/3534]
  * [Implement `cargo --version --verbose`][cargo/3604]
  * [All builds now output 'dep-info' build dependencies compatible with
  make and ninja][cargo/3557]
  * [Build all workspace members with `build --all`][cargo/3511]
  * [Document all workspace members with `doc --all`][cargo/3515]
  * [Path deps outside workspace are not members][cargo/3443]
* Wed Feb 15 2017 luke.nukem.jones@gmail.com
- Fixes to build for archs armv7, aarch64, ppc64, s390x
* Thu Feb  9 2017 luke.nukem.jones@gmail.com
- Update to 0.16.0
  * No changelog provided by upstream
* Tue Jan 31 2017 luke.nukem.jones@gmail.com
- Update to 0.15.0
  * [In this release, Cargo build scripts no longer have access to the `OUT_DIR`
    environment variable at build time via `env!("OUT_DIR")`][cargo/3368]. They
    should instead check the variable at runtime with `std::env`. That the value
    was set at build time was a bug, and incorrect when cross-compiling. This
    change is known to cause breakage.
  * [Add `--all` flag to `cargo test`][cargo/3221]
  * [Compile statically against the MSVC CRT][cargo/3363]
  * [Mix feature flags into fingerprint/metadata shorthash][cargo/3102]
  * [Link OpenSSL statically on OSX][cargo/3311]
  * [Apply new fingerprinting to build dir outputs][cargo/3310]
  * [Test for bad path overrides with summaries][cargo/3336]
  * [Require `cargo install --vers` to take a semver version][cargo/3338]
  * [Fix retrying crate downloads for network errors][cargo/3348]
  * [Implement string lookup for `build.rustflags` config key][cargo/3356]
  * [Emit more info on --message-format=json][cargo/3319]
  * [Assume `build.rs` in the same directory as `Cargo.toml` is a build script][cargo/3361]
  * [Don't ignore errors in workspace manifest][cargo/3409]
  * [Fix `--message-format JSON` when rustc emits non-JSON warnings][cargo/3410]
* Tue Jan 17 2017 bwiedemann@suse.com
- Add reproducible.patch to allow for reproducible builds
* Thu Nov  3 2016 matwey.kornilov@gmail.com
- Update to 0.13.0
  * This release includes security fixes to both curl and OpenSSL.
  * [Fix transitive doctests when panic=abort][cargo/3021]
  * [Add --all-features flag to cargo][cargo/3038]
  * [Reject path-based dependencies in `cargo package`][cargo/3060]
  * [Don't parse the home directory more than once][cargo/3078]
  * [Don't try to generate Cargo.lock on empty workspaces][cargo/3092]
  * [Update OpenSSL to 1.0.2j][cargo/3121]
  * [Add license and license_file to cargo metadata output][cargo/3110]
  * [Make crates-io registry URL optional in config; ignore all changes to
    source.crates-io][cargo/3089]
  * [Don't download dependencies from other platforms][cargo/3123]
  * [Build transitive dev-dependencies when needed][cargo/3125]
  * [Add support for per-target rustflags in .cargo/config][cargo/3157]
  * [Avoid updating registry when adding existing deps][cargo/3144]
  * [Warn about path overrides that won't work][cargo/3136]
  * [Use workspaces during `cargo install`][cargo/3146]
  * [Leak mspdbsrv.exe processes on Windows][cargo/3162]
  * [Add --message-format flag][cargo/3000]
  * [Pass target environment for rustdoc][cargo/3205]
  * [Use `CommandExt::exec` for `cargo run` on Unix][cargo/2818]
  * [Update curl and curl-sys][cargo/3241]
  * [Call rustdoc test with the correct cfg flags of a package][cargo/3242]
* Wed Aug 10 2016 kgronlund@suse.com
- Update to 0.11.0
  * Fix compilation using rustc 1.10
  * Implement the `panic` profile option
  * Don't throw away errors with `-p` arguments
* Sun Jul  3 2016 kgronlund@suse.com
- Revised packaging to rely on cargo-vendor
* Wed Jun 29 2016 kgronlund@suse.com
- Update to 0.10.0
- Revised packaging to rely on cargo-bootstrap project when building
* Sun Apr 17 2016 mvyskocil@opensuse.org
- Update to 0.9.0
* Wed Feb 10 2016 mvyskocil@opensuse.org
- Adapted version (per review request)
* Thu Jan 28 2016 mvyskocil@opensuse.org
- Initial packaging of cargo for openSUSE
